@@ -162,21 +162,20 @@ def definitely_click_b(driver, types: list, error_log=False):
             break
 
 
-def start_cookie(path='cookies.txt'):
+def start_cookie(driver, path='cookies.txt'):
     """
     - 使用 cookie
     :return:
 
     使用教程：
-    cookie_list = start_cookie()
-    if cookie_list:
-        for cookie in eval(cookie_list):
-            driver.add_cookie(cookie)
+        start_cookie(driver)
         driver.get('登录后的url，不是登录的url')
     """
-    print('使用 cookies')
     with open(path) as f:
-        return f.read()
+        if f.read():
+            for cookie in eval(f.read()):
+                driver.add_cookie(cookie)
+                print('使用 cookies')
 
 
 def update_cookie(driver, path='cookies.txt'):
@@ -188,9 +187,9 @@ def update_cookie(driver, path='cookies.txt'):
 
     一般都是搭配 py_selenium.start_cookie 方法一起使用。
     """
-    print('更新 cookies')
     with open(path, 'w') as f:
         f.write(str(driver.get_cookies()))
+        print('更新 cookies')
 
 
 def jump_iframe(driver, types: list, error_log=False):
